@@ -119,7 +119,7 @@ use Chj::xtmpfile;
 use Chj::xperlfunc qw(xexec xstat);
 use Chj::xopen qw(fh_to_fh perhaps_xopen_read);
 use POSIX;
-use Chj::xhome qw(xhome);
+use Chj::xhome qw(xsafehome);
 use Chj::singlequote 'singlequote';
 use FP::HashSet qw(hashset_union);
 use FP::Hash qw(hash_xref);
@@ -147,10 +147,10 @@ sub xone_nonwhitespace {
     $1
 }
 
-my $HOME = xhome;
+my $HOME = xsafehome;
 our $maybe_historypath        = "$HOME/.fp-repl_history";
 our $maybe_settingspath       = "$HOME/.fp-repl_settings";
-our $maxHistLen               = 100;
+our $maxHistLen               = 500;
 our $doCatchINT               = 1;
 our $doRepeatWhenEmpty        = 1;
 our $doKeepResultsInVARX      = 1;
@@ -1098,6 +1098,7 @@ sub run {
                                     $history_z++;
                                     redo TRY;
                                 }
+                                mkdir $$self[Maybe_historypath], 0700;
                                 my $f = xtmpfile $path;
                                 $f->xprint($input);
                                 $f->xclose;
